@@ -1,7 +1,7 @@
 from abc import ABC, abstractmethod
 import functools
 from os import PathLike
-from typing import (Any, Dict, Generic, Optional, Sequence, Tuple, TypeVar,
+from typing import (Any, Dict, Generic, Iterable, Optional, Sequence, Tuple, TypeVar,
                     Union)
 from instancelib.instances.base import InstanceProvider
 from instancelib.labels.base import LabelProvider
@@ -37,11 +37,7 @@ class AbstractPlotter(ABC, Generic[LT]):
         raise NotImplementedError
     
     @abstractmethod
-    def show(self,
-             x_lim: Optional[float] = None,
-             y_lim: Optional[float] = None,
-             all_estimations: bool = False,
-             filename: Optional[PathLike] = None) -> None:
+    def show(self, *args: Any, **kwargs: Any) -> None:
         raise NotImplementedError
 
 class ClassificationPlotter(AbstractPlotter[LT], Generic[KT, LT]):
@@ -49,20 +45,37 @@ class ClassificationPlotter(AbstractPlotter[LT], Generic[KT, LT]):
         self.test_set = list(test_set.values())
         self.ground_truth = ground_truth
         self.result_frame = pd.DataFrame()
+        self.labelset = ground_truth.labelset
 
     def update(self, activelearner: ActiveLearner[Any, KT, Any, Any, Any, LT]) -> None:
         assert isinstance(activelearner, MLBased)
         results = classifier_performance(activelearner, self.ground_truth, self.test_set)
-        labelset = activelearner.env.labels.labelset
         stats: Dict[str, float] = dict()
-        for label in labelset:
+        for label in self.labelset:
             label_performance = results[label]
+            stats[f"{label}_recall"] = label_performance.recall
+            stats[f"{label}_precision"] = label_performance.precision
             stats[f"{label}_f1"] = label_performance.f1
             stats[f"{label}_docs"] = activelearner.env.labels.document_count(label)
+            stats[f"{label}_ratio"] = (activelearner.env.labels.document_count(label) / len(activelearner.env.labeled))
         stats["n_labeled"] = len(activelearner.env.labeled)
         self.result_frame = self.result_frame.append(stats, ignore_index=True)
-
-
+    
+    def show(self, metrics: Iterable[str] = ["f1", "recall"], filename:Optional[str] = None) -> None:
+        # Gathering intermediate results
+        df = self.result_frame
+        n_labeled= df["n_labeled"]
+        for metric in metrics:
+            for label in self.labelset:
+                metric_values = df[f"{label}_{metric}"]
+                plt.plot(n_labeled, metric_values, label=f"{label} :: {metric}")
+        # Plotting positive document counts
+        plt.xlabel(f"number of labeled instances")
+        plt.ylabel(f"metric score")
+        plt.title(f"Learning curves")
+        plt.legend(bbox_to_anchor=(1.05, 1), loc='upper left')
+        if filename is not None:
+            plt.savefig(filename, bbox_inches='tight')
 
 
 class MultilabelPlotter(AbstractPlotter[LT], Generic[LT]):
